@@ -17,7 +17,7 @@ command line). This extension uses and wraps services of the keyring
 library.
 '''
 
-from mercurial import hg, repo, util
+from mercurial import hg, util
 from mercurial.i18n import _
 try:
     from mercurial.url import passwordmgr
